@@ -46,13 +46,12 @@ def _get_page_titles(artist, title):
         "format": "json",
         }
     
-    titles = []
+    titles = ["%s:%s" %(artist.title(), title.title())]
     content = json.loads(_download(args))
-    for title in content["query"]["search"]:
-        titles.append(title["title"])
+    for t in content["query"]["search"]:
+        titles.append(t["title"])
     
-    titles.append("%s:%s" %(artist.title(), title.title()))
-    return set(titles)
+    return titles
 
 def _get_lyrics(artist, title):
     
@@ -106,3 +105,5 @@ def get_lyrics(artist, title, cache_dir=None):
         fp.close()
     
     return lyrics
+
+print get_lyrics("wolfmother", "eyes open")
